@@ -48,7 +48,8 @@ public:
         ShutdownMode = 8,
         LogoutDialogMode = 16,
         LockScreenMode = 32,
-        TurnOffScreenMode = 64
+        TurnOffScreenMode = 64,
+        ToggleScreenOnOffMode = 128
     };
 
     explicit SuspendSession(QObject *parent);
