@@ -80,7 +80,7 @@ private slots:
     void slotDeviceRemoved(const QDBusObjectPath & path);
     void slotDeviceChanged(const QString &);
     void slotPropertyChanged();
-    void slotLogin1Resuming(bool active);
+    void slotLogin1PrepareForSleep(bool active);
     void slotScreenBrightnessChanged();
     void onDeviceChanged(const UdevQt::Device &device);
     void onKeyboardBrightnessChanged(int);
@@ -109,7 +109,7 @@ private:
     QPropertyAnimation *m_brightnessAnimation = nullptr;
 
     // login1 interface
-    QWeakPointer<QDBusInterface> m_login1Interface;
+    QPointer<QDBusInterface> m_login1Interface;
     bool m_useUPowerSuspend = false;
 
     // buttons
